# Crystal DBA Terminal UI (tui)

## Starting the app

```bash
cd tui
python -m tui
```

## Attribution

This started from the impressive [Elia Chat](https://github.com/darrenburns/elia). Thank you Darren.
